commit 438fed6b62a49e266d17101c1d46af25ae301271
Author: Jean-Marc Lasgouttes <lasgout...@lyx.org>
Date:   Wed Oct 23 14:14:04 2024 +0200

    Mac OS X is macOS these days
---
 INSTALL.autoconf                    |  2 +-
 NEWS                                |  6 +++---
 src/AspellChecker.cpp               |  2 +-
 src/Format.cpp                      |  2 +-
 src/LyXRC.cpp                       |  2 +-
 src/Paragraph.cpp                   |  2 +-
 src/frontends/qt/GuiApplication.cpp |  6 +++---
 src/frontends/qt/GuiClipboard.cpp   |  4 ++--
 src/frontends/qt/GuiView.cpp        |  4 ++--
 src/frontends/qt/Menus.cpp          | 16 ++++++++--------
 src/frontends/qt/ui/PrefInputUi.ui  |  2 +-
 src/support/Package.h               |  2 +-
 src/support/convert.cpp             |  2 +-
 src/support/socktools.cpp           |  2 +-
 14 files changed, 27 insertions(+), 27 deletions(-)

diff --git a/INSTALL.autoconf b/INSTALL.autoconf
index d290c6e6f4..febfed27f0 100644
--- a/INSTALL.autoconf
+++ b/INSTALL.autoconf
@@ -125,7 +125,7 @@ architecture at a time in the source code directory.  After 
you have
 installed the package for one architecture, use 'make distclean' before
 reconfiguring for another architecture.
 
-   On MacOS X 10.5 and later systems, you can create libraries and
+   On Mac OS X 10.5 and later systems, you can create libraries and
 executables that work on multiple system types--known as "fat" or
 "universal" binaries--by specifying multiple '-arch' options to the
 compiler but only a single '-arch' option to the preprocessor.  Like
diff --git a/NEWS b/NEWS
index 0a816c2e71..1f9aca76d5 100644
--- a/NEWS
+++ b/NEWS
@@ -106,7 +106,7 @@ python 2.x and python 3.x.
 
 One oft-requested enhancement was to restore a keyboard shortcut for opening
 the 'settings' menu of graphics, reference, etc, insets. This is now Control-
-Alt-i, on Windows and Linux, and Control-Option-i on OSX (assuming you are
+Alt-i, on Windows and Linux, and Control-Option-i on macOS (assuming you are
 using the default keybindings).
 
 
@@ -1143,7 +1143,7 @@ All current 1.3.x users are encouraged to upgrade to this 
version.
 What's new in version 1.3.6?
 ----------------------------
 
-Unix and MacOSX users should consider this to be a bugfix release.
+Unix and Mac OS X users should consider this to be a bugfix release.
 
 To Windows users, however, LyX 1.3.6 is the first version of LyX
 to support the platform officially. This means that we've put a huge
@@ -1195,7 +1195,7 @@ This is a maintenance release which improves upon 1.3.2 in
 four main areas:
   * import of old LyX files and export to DocBook have been improved;
   * many small bugs in the Qt frontend have been fixed;
-  * MacOSX users can now compile LyX and enjoy the native MacOSX interface;
+  * Mac OS X users can now compile LyX and enjoy the native Mac OS X interface;
   * several languages now benefit from an improved translation of
     the user interface and documentation.
 
diff --git a/src/AspellChecker.cpp b/src/AspellChecker.cpp
index a5c54d8c74..42bc52277f 100644
--- a/src/AspellChecker.cpp
+++ b/src/AspellChecker.cpp
@@ -102,7 +102,7 @@ struct AspellChecker::Private
                return "data";
        }
        /// os package directory constants
-       /// macports on Mac OS X or
+       /// macports on macOS or
        /// aspell rpms on Linux
        const string osPackageBase(void)
        {
diff --git a/src/Format.cpp b/src/Format.cpp
index 7128e2a774..89264c6177 100644
--- a/src/Format.cpp
+++ b/src/Format.cpp
@@ -733,7 +733,7 @@ bool Formats::edit(Buffer const & buffer, FileName const & 
filename,
                return editLinkBackFile(filename.absFileName().c_str());
 #else
                Alert::error(_("Cannot edit file"),
-                            _("LinkBack files can only be edited on Apple Mac 
OSX."));
+                            _("LinkBack files can only be edited on macOS."));
                return false;
 #endif // USE_MACOSX_PACKAGING
        }
diff --git a/src/LyXRC.cpp b/src/LyXRC.cpp
index ce0d4ee92a..60c7f23814 100644
--- a/src/LyXRC.cpp
+++ b/src/LyXRC.cpp
@@ -3203,7 +3203,7 @@ string const LyXRC::getDescription(LyXRCTags tag)
                break;
 
        case RC_MAC_LIKE_CURSOR_MOVEMENT:
-               str = _("Use the Mac OS X conventions for cursor movement");
+               str = _("Use the macOS conventions for cursor movement");
                break;
 
        case RC_SHOW_MACRO_LABEL:
diff --git a/src/Paragraph.cpp b/src/Paragraph.cpp
index 23ba81fa86..1f1940e1da 100644
--- a/src/Paragraph.cpp
+++ b/src/Paragraph.cpp
@@ -72,7 +72,7 @@
 using namespace std;
 using namespace lyx::support;
 
-// OSX clang and msvc < 2015 do not support C++11 thread_local
+// (old?) macOS clang and msvc < 2015 do not support C++11 thread_local
 #if defined(__APPLE__)
 #define THREAD_LOCAL_STATIC static __thread
 #elif defined(_MSC_VER) && (_MSC_VER < 1900)
diff --git a/src/frontends/qt/GuiApplication.cpp 
b/src/frontends/qt/GuiApplication.cpp
index 9cbcdbb386..83844d5a6c 100644
--- a/src/frontends/qt/GuiApplication.cpp
+++ b/src/frontends/qt/GuiApplication.cpp
@@ -1094,7 +1094,7 @@ struct GuiApplication::Private
        Qt::ApplicationState last_state_;
 
 #if defined(Q_OS_MAC) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-       /// Linkback mime handler for MacOSX.
+       /// Linkback mime handler for macOS.
        QMacPasteboardMimeGraphics mac_pasteboard_mime_;
 #endif
 
@@ -1172,7 +1172,7 @@ GuiApplication::GuiApplication(int & argc, char ** argv)
 
        if (platformName() == "xcb") {
                // doubleClickInterval() is 400 ms on X11 which is just too 
long.
-               // On Windows and Mac OS X, the operating system's value is 
used.
+               // On Windows and macOS, the operating system's value is used.
                // On Microsoft Windows, calling this function sets the double
                // click interval for all applications. So we don't!
                QApplication::setDoubleClickInterval(300);
@@ -2972,7 +2972,7 @@ bool GuiApplication::event(QEvent * e)
 {
        switch(e->type()) {
        case QEvent::FileOpen: {
-               // Open a file; this happens only on Mac OS X for now.
+               // Open a file; this happens only on macOS for now.
                //
                // We do this asynchronously because on startup the batch
                // commands are not executed here yet and the gui is not ready
diff --git a/src/frontends/qt/GuiClipboard.cpp 
b/src/frontends/qt/GuiClipboard.cpp
index 6303e40c65..43a0aecf9a 100644
--- a/src/frontends/qt/GuiClipboard.cpp
+++ b/src/frontends/qt/GuiClipboard.cpp
@@ -541,11 +541,11 @@ bool GuiClipboard::isInternal() const
 
 bool GuiClipboard::hasInternal() const
 {
-       // Windows and Mac OS X does not have the concept of ownership;
+       // Windows and macOS does not have the concept of ownership;
        // the clipboard is a fully global resource so all applications
        // are notified of changes. However, on Windows ownership is
        // emulated by Qt through the OleIsCurrentClipboard() API, while
-       // on Mac OS X we deal with this issue by ourself.
+       // on macOS we deal with this issue by ourself.
 #ifndef Q_OS_MAC
        return true;
 #else
diff --git a/src/frontends/qt/GuiView.cpp b/src/frontends/qt/GuiView.cpp
index 624b2413c5..de796ad01c 100644
--- a/src/frontends/qt/GuiView.cpp
+++ b/src/frontends/qt/GuiView.cpp
@@ -1523,7 +1523,7 @@ void GuiView::updateWindowTitle(GuiWorkArea * wa)
        }
        title += from_ascii(" - LyX");
        setWindowTitle(toqstr(title));
-       // Sets the path for the window: this is used by OSX to
+       // Sets the path for the window: this is used by macOS to
        // allow a context click on the title bar showing a menu
        // with the path up to the file
        setWindowFilePath(toqstr(buf.absFileName()));
@@ -1788,7 +1788,7 @@ bool GuiView::event(QEvent * e)
        }
 #else
        // Pre 6.8: OS-dependent
-       // 1. Mac OS X
+       // 1. macOS
        // Limit to Q_OS_MAC as this unnecessarily would also
        // trigger on Linux with grave performance issues
 #ifdef Q_OS_MAC
diff --git a/src/frontends/qt/ui/PrefInputUi.ui 
b/src/frontends/qt/ui/PrefInputUi.ui
index 90ebcbe60c..109d1a0b09 100644
--- a/src/frontends/qt/ui/PrefInputUi.ui
+++ b/src/frontends/qt/ui/PrefInputUi.ui
@@ -98,7 +98,7 @@
       <item row="3" column="0" colspan="3">
        <widget class="QCheckBox" name="dontswapCB">
         <property name="toolTip">
-         <string>Mac OS X specific setting for use with emacs bindings. Takes 
effect next time LyX is launched.</string>
+         <string>macOS specific setting for use with emacs bindings. Takes 
effect next time LyX is launched.</string>
         </property>
         <property name="text">
          <string>Do not swap Apple and Control keys</string>
diff --git a/src/support/Package.h b/src/support/Package.h
index 62db5d2b17..e303329cb5 100644
--- a/src/support/Package.h
+++ b/src/support/Package.h
@@ -10,7 +10,7 @@
  *
  * A store of the paths to the various different directories used
  * by LyX. These paths differ markedly from one OS to another,
- * following the local Windows, MacOS X or Posix conventions.
+ * following the local Windows, macOS or Posix conventions.
  */
 
 #ifndef PACKAGE_H
diff --git a/src/support/convert.cpp b/src/support/convert.cpp
index d172469bc8..74907da183 100644
--- a/src/support/convert.cpp
+++ b/src/support/convert.cpp
@@ -15,7 +15,7 @@
 #include "support/docstring.h"
 
 #include <sstream>
-//needed for Mac OSX 10.5.2 Leopard
+// needed for Mac OS X 10.5.2 Leopard
 #include <cstdlib>
 
 using namespace std;
diff --git a/src/support/socktools.cpp b/src/support/socktools.cpp
index d014f45e94..77e5b3e99b 100644
--- a/src/support/socktools.cpp
+++ b/src/support/socktools.cpp
@@ -51,7 +51,7 @@ int accept(int)
 
 #include <cerrno>
 #include <string>
-//needed for Mac OSX 10.5.2 Leopard
+// needed for Mac OS X 10.5.2 Leopard
 #include <cstring>
 
 using namespace std;
diff --git a/src/frontends/qt/Menus.cpp b/src/frontends/qt/Menus.cpp
index 480c03013d..5f7c8c3f98 100644
--- a/src/frontends/qt/Menus.cpp
+++ b/src/frontends/qt/Menus.cpp
@@ -92,7 +92,7 @@ namespace frontend {
 
 namespace {
 
 // MacOSX specific stuff is at the end.
 
 class MenuDefinition;
 
@@ -2327,8 +2327,8 @@ struct Menus::Impl {
        void expand(MenuDefinition const & frommenu, MenuDefinition & tomenu,
                BufferView const *) const;
 
-       /// Initialize specific MACOS X menubar
-       void macxMenuBarInit(QMenuBar * qmb);
+       /// Initialize specific macOS menubar
+       void macMenuBarInit(QMenuBar * qmb);
 
        /// Mac special menu.
        /** This defines a menu whose entries list the FuncRequests
@@ -2378,9 +2378,9 @@ MenuDefinition Menus::Impl::mac_special_menu_;
   that this menubar will be used also when one of LyX' dialogs has
   focus. (JMarc)
 */
-void Menus::Impl::macxMenuBarInit(QMenuBar * qmb)
+void Menus::Impl::macMenuBarInit(QMenuBar * qmb)
 {
        /* The qt/mac menu code has special code for specifying the role
           of a menu entry. However, it does not work very well with our
           scheme of creating menus on demand, and therefore we need to
           put these entries in a special invisible menu. (JMarc)
@@ -2410,7 +2410,7 @@ void Menus::Impl::macxMenuBarInit(QMenuBar * qmb)
        const size_t num_entries = sizeof(entries) / sizeof(entries[0]);
        const bool first_call = mac_special_menu_.empty();
 
-       LYXERR(Debug::GUI, "Creating Mac OS X special menu bar");
+       LYXERR(Debug::GUI, "Creating macOS special menu bar");
        // the special menu for Menus. Fill it up only once.
        if (first_call) {
                for (size_t i = 0 ; i < num_entries ; ++i) {
@@ -2726,13 +2726,13 @@ void Menus::fillMenuBar(QMenuBar * qmb, GuiView * view, 
bool initial)
                // the first time a QMenuBar is created. Otherwise Qt will
                // create duplicate items in the application menu. It seems
                // that Qt does not remove them when the QMenubar is cleared.
-               d->macxMenuBarInit(qmb);
+               d->macMenuBarInit(qmb);
 #endif
        } else {
                // Clear all menubar contents before filling it.
                qmb->clear();
 #if (defined(Q_OS_MAC))
-               d->macxMenuBarInit(qmb);
+               d->macMenuBarInit(qmb);
 #endif
        }
 
@@ -92,7 +92,7 @@ namespace frontend {
 namespace {
 
-// MacOSX specific stuff is at the end.
+// macOS specific stuff is at the end.
 
 class MenuDefinition;
@@ -2378,9 +2378,9 @@ MenuDefinition Menus::Impl::mac_special_menu_;
 {
-       /* The qt/mac menu code has special code for specifying the role
+       /* The macOS menu code has special code for specifying the role
           of a menu entry. However, it does not work very well with our
           scheme of creating menus on demand, and therefore we need to
-- 
lyx-cvs mailing list
lyx-cvs@lists.lyx.org
https://lists.lyx.org/mailman/listinfo/lyx-cvs

Reply via email to